@@ -67,23 +67,23 @@ sub check_keep_config($$$)
 
 	if ("$configDesc" eq "")
 	{
-		$prompt="$ROOT$configFile";
+		$prompt="$configFile";
 	} else {
-		$prompt="$configDesc ($ROOT$configFile)";
+		$prompt="$configDesc ($configFile)";
 	}
 
-	if (! exists $KeepConfig{"$ROOT$configFile"})
+	if (! exists $KeepConfig{"$configFile"})
 	{
-		$keep=system "diff $ROOT$configFile $ROOT$configFile-sample > /dev/null 2>&1";
+		$keep=system "diff $configFile $configFile-sample > /dev/null 2>&1";
 		if ($keep != 0)
 		{
-			NormalPrint "You have a modified $ROOT$configFile configuration file\n";
-			$KeepConfig{"$ROOT$configFile"} = GetYesNo("Do you want to keep $prompt?", "$default");
+			NormalPrint "You have a modified $configFile configuration file\n";
+			$KeepConfig{"$configFile"} = GetYesNo("Do you want to keep $prompt?", "$default");
 		} else {
-			$KeepConfig{"$ROOT$configFile"} = $keep;
+			$KeepConfig{"$configFile"} = $keep;
 		}
 	}
-	return $KeepConfig{"$ROOT$configFile"};
+	return $KeepConfig{"$configFile"};
 }
 
 # This is to update the old path when upgrading from 10.3 to newer version
@@ -160,7 +160,7 @@ sub clear_keep_config($)
 {
 	my($configFile) = shift();
 
-	delete $KeepConfig{"$ROOT$configFile"};
+	delete $KeepConfig{"$configFile"};
 }
 
 sub remove_conf_file($$)
@@ -168,16 +168,16 @@ sub remove_conf_file($$)
 	my($WhichDriver) = shift();
 	my($ConfFile) = shift();
 
-	if (-e "$ROOT$ConfFile") 
+	if (-e "$ConfFile") 
 	{
 		if (check_keep_config("$ConfFile", "$WhichDriver configuration file", "y"))
 		{
-			NormalPrint "Keeping $WhichDriver configuration file ($ROOT$ConfFile) ...\n";
+			NormalPrint "Keeping $WhichDriver configuration file ($ConfFile) ...\n";
 		} else {
-			system "rm -rf $ROOT$ConfFile";
+			system "rm -rf $ConfFile";
 		}
 	}
-	system "rm -rf $ROOT${ConfFile}-sample";
+	system "rm -rf ${ConfFile}-sample";
 }
 
 # remove a config file where a previous release used a different name for
@@ -208,19 +208,19 @@ sub install_conf_file($$$;@)
 
 	# install an appropriate file into $ConfFileDest
 	foreach my $OldConfFileDest ( @OldConfFileDest_list, $ConfFileDest ) {
-		DebugPrint("Checking $ROOT$OldConfFileDest\n");
-		next if ( ! -e "$ROOT$OldConfFileDest" );
+		DebugPrint("Checking $OldConfFileDest\n");
+		next if ( ! -e "$OldConfFileDest" );
 
-		$diff_src_dest = system "diff $ConfFileSrc $ROOT$OldConfFileDest > /dev/null 2>&1";
+		$diff_src_dest = system "diff $ConfFileSrc $OldConfFileDest > /dev/null 2>&1";
 
 		if ( ! -e "${OldConfFileDest}-sample" )
 		{
-			DebugPrint("No $ROOT${OldConfFileDest}-sample\n");
+			DebugPrint("No ${OldConfFileDest}-sample\n");
 			$diff_src_sample=1;
 			$diff_dest_sample=1;
 		} else {
-			$diff_src_sample = system "diff $ConfFileSrc $ROOT${OldConfFileDest}-sample > /dev/null 2>&1";
-			$diff_dest_sample = system "diff $OldConfFileDest $ROOT${OldConfFileDest}-sample > /dev/null 2>&1";
+			$diff_src_sample = system "diff $ConfFileSrc ${OldConfFileDest}-sample > /dev/null 2>&1";
+			$diff_dest_sample = system "diff $OldConfFileDest ${OldConfFileDest}-sample > /dev/null 2>&1";
 		}
 		DebugPrint("Comparisons: src vs old=$diff_src_dest, src vs oldsample=$diff_src_sample, old vs oldsample=$diff_dest_sample\n");
 
@@ -241,11 +241,11 @@ sub install_conf_file($$$;@)
 			if ( $keep ) {
 				if ("$OldConfFileDest" ne "$ConfFileDest") {
 					# we are working on an old config file
-					copy_data_file("$ROOT$OldConfFileDest", "$ConfFileDest");
-					NormalPrint "Using $ROOT$OldConfFileDest as $ROOT$ConfFileDest...\n";
+					copy_data_file("$OldConfFileDest", "$ConfFileDest");
+					NormalPrint "Using $OldConfFileDest as $ConfFileDest...\n";
 				} else {
 					# we are working against the new supplied config file
-					NormalPrint "Leaving $ROOT$OldConfFileDest unchanged...\n";
+					NormalPrint "Leaving $OldConfFileDest unchanged...\n";
 				}
 				$need_copy=0;
 				last;
@@ -254,11 +254,11 @@ sub install_conf_file($$$;@)
 	}
 	if ( $need_copy) {
 		# no old files kept (or not found), use new release version
-		NormalPrint "Updating $ROOT$ConfFileDest ...\n";
+		NormalPrint "Updating $ConfFileDest ...\n";
 		copy_data_file("$ConfFileSrc", "$ConfFileDest");
 	}
 	foreach my $OldConfFileDest ( @OldConfFileDest_list ) {
-		system "rm -rf $ROOT${OldConfFileDest}-sample";
+		system "rm -rf ${OldConfFileDest}-sample";
 	}
 	copy_file("$ConfFileSrc", "${ConfFileDest}-sample", "$OWNER", "$GROUP", "ugo=r,u=r");
 }
@@ -271,13 +271,13 @@ sub copy_rpm_conf_file($$;@)
 	my($WhichDriver) = shift();
 	my($ConfFileDest) = shift();
 	my(@OldConfFileDest_list) = @_;	# optional
-	my($ConfFileSrc) = "$ROOT$ConfFileDest.rpmnew";
+	my($ConfFileSrc) = "$ConfFileDest.rpmnew";
 
-	if ( ! -e "$ROOT$ConfFileDest.rpmnew" )
+	if ( ! -e "$ConfFileDest.rpmnew" )
 	{
 		# must be first install, Dest is the newest file
 		# save a copy in case we overwrite it with an OldConfFileDest below
-		system("cp $ROOT$ConfFileDest $TMP_CONF");
+		system("cp $ConfFileDest $TMP_CONF");
 		$ConfFileSrc="$TMP_CONF"
 	}
 	install_conf_file($WhichDriver, $ConfFileDest, $ConfFileSrc, @OldConfFileDest_list);
@@ -289,19 +289,19 @@ sub copy_rpm_conf_file($$;@)
 sub preserve_prev_rpm_conf($)
 {
 	my($ConfFileDest) = shift();
-	my($ConfFileSave) = "$ROOT$ConfFileDest.rpmsave";
+	my($ConfFileSave) = "$ConfFileDest.rpmsave";
 	
 	if ( -e "$ConfFileSave" )
 	{
 		#install_conf_file($WhichDriver, $ConfFileDest, $ConfFileSave);
 		#system("rm -f $ConfFileSave");
-		my $diff_src_dest = system "diff $ROOT$ConfFileDest $ConfFileSave > /dev/null 2>&1";
+		my $diff_src_dest = system "diff $ConfFileDest $ConfFileSave > /dev/null 2>&1";
 		if ($diff_src_dest != 0) {
-			printf("You have a modified $ROOT$ConfFileDest configuration file \n");
-			my $keep = GetYesNo("Do you want to keep $ROOT$ConfFileDest?", "y");
+			printf("You have a modified $ConfFileDest configuration file \n");
+			my $keep = GetYesNo("Do you want to keep $ConfFileDest?", "y");
 			if ($keep) {
 				printf("Using the modified $ConfFileDest file \n");
-				copy_data_file("$ConfFileSave", "$ROOT$ConfFileDest");
+				copy_data_file("$ConfFileSave", "$ConfFileDest");
 			}
 			else {
 				printf("Using the new $ConfFileDest file \n");
@@ -325,7 +325,7 @@ sub install_renamed_conf_file($$$;@)
 	my $diff_src_sample;
 	my $diff_dest_sample;
 
-	if (! -e "$ROOT$ConfFileDest") {
+	if (! -e "$ConfFileDest") {
 		# first upgrade install, we consider old files as relevant
 		# we want to do the install_conf_file algorithm
 		# but use OldConfFileDest for all but file destination of copy
@@ -333,7 +333,7 @@ sub install_renamed_conf_file($$$;@)
 	} else {
 		# don't touch old (if any), just perform normal upgrade/install
 		foreach my $OldConfFileDest ( @OldConfFileDest_list ) {
-			system "rm -rf $ROOT${OldConfFileDest}-sample";
+			system "rm -rf ${OldConfFileDest}-sample";
 		}
 		install_conf_file("$WhichDriver","$ConfFileDest","$ConfFileSrc");
 	}
@@ -395,51 +395,6 @@ sub del_marks($$$$)
 	system "mv $TMP_CONF $FileName";
 }
 
-sub ins_marks($$$$)
-{
-	my($StartMark) = shift();
-	my($EndMark) = shift();
-	my($Contents) = shift();
-	my($FileName) = shift();
-
-	my($found_mark)=0;
-	my($ReadEnd) = "";
-
-	open (INPUT, "$FileName");
-	open (OUTPUT, ">>$TMP_CONF");
-
-	select (OUTPUT);
-	while (($found_mark == 0) && ($_=<INPUT>)) {
-		if (/$StartMark/) {
-			$found_mark=1;
-			print $_;
-		} else {
-			print $_;
-		}
-	}
-
-	while (($found_mark == 1) && ($_=<INPUT>)) {
-		if (/$EndMark/) {
-			$found_mark = 0;
-			$ReadEnd = $_;
-		} 
-	}
-
-	print $Contents;
-	print $ReadEnd;
-
-	while ($_=<INPUT>) {
-		print $_;
-	}
-
-	select(STDOUT);
-
-	close (INPUT);
-	close (OUTPUT);
-
-	system "mv $TMP_CONF $FileName";
-}
-
 # gets contents including marks and compares to specified file
 # returns 0 on match, 1 if different
 sub compare_marks($$$$)
@@ -466,52 +421,6 @@ sub compare_marks($$$$)
 	return $is_different
 }
 
-sub	edit_conf_file($$$$$)
-{
-	my($SourceFile) = shift();
-	my($DestFile) = shift();
-	my($FileDesc) = shift();
-	my($StartMarker) = shift();
-	my($EndMarker) = shift();
-
-	my $is_different;
-	my $found_inf;
-
-	if (! -e "$ROOT$DestFile")
-	{
-		Abort "$FileDesc file $ROOT$DestFile is missing";
-	}
-
-	NormalPrint "Updating $FileDesc...\n";
-	$found_inf = `grep "$StartMarker" $ROOT$DestFile`;
-
-	# if the iba section does not exist then just add and then return
-	if ($found_inf eq "") 
-	{
-		system "cat $SourceFile >> $ROOT$DestFile";
-		return;
-	}
-
-	# found an iba section so lets extract the iba section and compare it to the new section
-	$is_different = compare_marks ("$StartMarker", "$EndMarker", "$ROOT$DestFile", "$SourceFile");
-
-	if ($is_different) 
-	{
-		NormalPrint "You have $FileDesc entries for IB drivers from an earlier install\n";
-		if (check_keep_config($DestFile, "", "y"))
-		{
-			NormalPrint "Leaving $ROOT$DestFile unchanged...\n";
-		} 
-		else
-		{
-			# delete old section and markers
-			del_marks ("$StartMarker", "$EndMarker", 0, "$ROOT$DestFile");
-			# add in the new
-			system "cat $SourceFile >> $ROOT$DestFile";
-		}
-	}
-}
-
 # ===========================================================================
 # functions to edit simple config files
 
@@ -575,14 +484,14 @@ sub change_openib_conf_param($$)
 {
 	my $p1=shift();
 	my $p2=shift();
-	change_conf_param($p1,$p2,"$ROOT/$OFED_CONFIG");
+	change_conf_param($p1,$p2,"/$OFED_CONFIG");
 }
 
 sub change_opa_conf_param($$)
 {
 	my $p1=shift();
 	my $p2=shift();
-	change_conf_param($p1,$p2,"$ROOT/$OPA_CONFIG");
+	change_conf_param($p1,$p2,"/$OPA_CONFIG");
 }
 
 sub read_openib_conf_param($$)
@@ -591,7 +500,7 @@ sub read_openib_conf_param($$)
 	my $config_file=shift();	# if "", defaults to standard file
 
 	if ( "$config_file" eq "" ) {
-		$config_file="$ROOT/$OFED_CONFIG";
+		$config_file="/$OFED_CONFIG";
 	}
 	return read_simple_config_param($config_file, $parameter);
 }
@@ -602,7 +511,7 @@ sub read_opa_conf_param($$)
 	my $config_file=shift();	# if "", defaults to standard file
 
 	if ( "$config_file" eq "" ) {
-		$config_file="$ROOT/$OPA_CONFIG";
+		$config_file="/$OPA_CONFIG";
 	}
 	return read_simple_config_param($config_file, $parameter);
 }
@@ -656,7 +565,7 @@ sub prompt_openib_conf_param($$$;$)
 	my $OPA_INSTALL_ENV=shift();
 
 	prompt_conf_param($parameter, $parameterDesc, $default, 
-		"$ROOT/$OFED_CONFIG", $OPA_INSTALL_ENV);
+		"/$OFED_CONFIG", $OPA_INSTALL_ENV);
 }
 
 sub prompt_opa_conf_param($$$;$)
@@ -667,5 +576,5 @@ sub prompt_opa_conf_param($$$;$)
 	my $OPA_INSTALL_ENV=shift();
 
 	prompt_conf_param($parameter, $parameterDesc, $default, 
-		"$ROOT/$OPA_CONFIG", $OPA_INSTALL_ENV);
+		"/$OPA_CONFIG", $OPA_INSTALL_ENV);
 }
